==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/consumption/kotlin/outputs/BudgetFilterResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.consumption.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 * May be used to filter budgets by resource group, resource, or meter.
 * @property and The logical "AND" expression. Must have at least 2 items.
 * @property dimensions Has comparison expression for a dimension
 * @property tags Has comparison expression for a tag
 */
public data class BudgetFilterResponse(
    public val and: List<BudgetFilterPropertiesResponse>? = null,
    public val dimensions: BudgetComparisonExpressionResponse? = null,
    public val tags: BudgetComparisonExpressionResponse? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.consumption.outputs.BudgetFilterResponse):
            BudgetFilterResponse = BudgetFilterResponse(
            and = javaType.and().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.consumption.kotlin.outputs.BudgetFilterPropertiesResponse.Companion.toKotlin(args0)
                })
            }),
            dimensions = javaType.dimensions().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.consumption.kotlin.outputs.BudgetComparisonExpressionResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            tags = javaType.tags().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.consumption.kotlin.outputs.BudgetComparisonExpressionResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/consumption/kotlin/outputs/BudgetFilterResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.consumption.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 * May be used to filter budgets by resource group, resource, or meter.
 * @property and The logical "AND" expression. Must have at least 2 items.
 * @property dimensions Has comparison expression for a dimension
 * @property tags Has comparison expression for a tag
 */
public data class BudgetFilterResponse(
    public val and: List<BudgetFilterPropertiesResponse>? = null,
    public val dimensions: BudgetComparisonExpressionResponse? = null,
    public val tags: BudgetComparisonExpressionResponse? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.consumption.outputs.BudgetFilterResponse): BudgetFilterResponse = BudgetFilterResponse(
            and = javaType.and().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.consumption.kotlin.outputs.BudgetFilterPropertiesResponse.Companion.toKotlin(args0)
                })
            }),
            dimensions = javaType.dimensions().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.consumption.kotlin.outputs.BudgetComparisonExpressionResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            tags = javaType.tags().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.consumption.kotlin.outputs.BudgetComparisonExpressionResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
        )
    }
}
